.. sinabs-dynapcnn documentation master file, created by
   sphinx-quickstart on Fri Jun 12 16:48:59 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sinabs-dynapcnn's documentation!
===========================================

This `sinabs` plugin enables porting sinabs models to chips and dev-kits with DYNAP-CNN technology.

To get started take a look at the

- The documentation below
- :doc:`cnn-to-dynapcnn tutorial<notebooks/cnn_to_dynapcnn>`.
- `examples <https://gitlab.com/synsense/sinabs-dynapcnn/~/tree/master/examples>`_

Table of contents
-----------------
.. toctree::
   :maxdepth: 2

   installation
   dynapcnn_compatible_model
   advanced_concepts
   dangers
   tutorials
   api/api.rst
   development


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
